You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@geode.apache.org by kl...@apache.org on 2016/02/01 21:55:50 UTC

[33/50] [abbrv] incubator-geode git commit: GEODE-805: Fix javadoc warnings.

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/172135e2/gemfire-core/src/test/java/com/gemstone/gemfire/management/internal/web/controllers/WanCommandsControllerJUnitTest.java
----------------------------------------------------------------------
diff --git a/gemfire-core/src/test/java/com/gemstone/gemfire/management/internal/web/controllers/WanCommandsControllerJUnitTest.java b/gemfire-core/src/test/java/com/gemstone/gemfire/management/internal/web/controllers/WanCommandsControllerJUnitTest.java
index 4c3fbe6..34781b2 100755
--- a/gemfire-core/src/test/java/com/gemstone/gemfire/management/internal/web/controllers/WanCommandsControllerJUnitTest.java
+++ b/gemfire-core/src/test/java/com/gemstone/gemfire/management/internal/web/controllers/WanCommandsControllerJUnitTest.java
@@ -83,7 +83,7 @@ public class WanCommandsControllerJUnitTest {
    * would only be rejected at runtime by the overall framework and is tested 
    * within an integration test.
    *
-   * @see WanCommandGatewaySenderStartDUnitTest
+   * see WanCommandGatewaySenderStartDUnitTest
    */
   @Test
   public void shouldDefineStartGatewayReceiverCommandWithNullGatewaySenderId() {
@@ -100,7 +100,7 @@ public class WanCommandsControllerJUnitTest {
    * would only be rejected at runtime by the overall framework and is tested 
    * within an integration test.
    *
-   * @see WanCommandGatewaySenderStartDUnitTest
+   * see WanCommandGatewaySenderStartDUnitTest
    */
   @Test
   public void shouldDefineStartGatewayReceiverCommandWithEmptyGatewaySenderId() {

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/172135e2/gemfire-core/src/test/java/com/gemstone/gemfire/security/P2PAuthenticationDUnitTest.java
----------------------------------------------------------------------
diff --git a/gemfire-core/src/test/java/com/gemstone/gemfire/security/P2PAuthenticationDUnitTest.java b/gemfire-core/src/test/java/com/gemstone/gemfire/security/P2PAuthenticationDUnitTest.java
index 2ff0b2e..5ba7044 100644
--- a/gemfire-core/src/test/java/com/gemstone/gemfire/security/P2PAuthenticationDUnitTest.java
+++ b/gemfire-core/src/test/java/com/gemstone/gemfire/security/P2PAuthenticationDUnitTest.java
@@ -489,8 +489,6 @@ public class P2PAuthenticationDUnitTest extends DistributedTestCase {
   /**
    * The strategy is to test credential size greater than UDP datagram size.
    * 
-   * @see Bug # 38570.
-   * 
    * Here locator will accept the credentials from peer2 and the large credential
    * from the first peer. Number of members in the DS
    * should be four

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/172135e2/gemfire-core/src/test/java/com/gemstone/gemfire/test/dunit/DistributedTestCase.java
----------------------------------------------------------------------
diff --git a/gemfire-core/src/test/java/com/gemstone/gemfire/test/dunit/DistributedTestCase.java b/gemfire-core/src/test/java/com/gemstone/gemfire/test/dunit/DistributedTestCase.java
index 80f5a47..d238dcd 100755
--- a/gemfire-core/src/test/java/com/gemstone/gemfire/test/dunit/DistributedTestCase.java
+++ b/gemfire-core/src/test/java/com/gemstone/gemfire/test/dunit/DistributedTestCase.java
@@ -166,7 +166,7 @@ public abstract class DistributedTestCase extends TestCase implements java.io.Se
    * Invokes a <code>SerializableRunnable</code> in every VM that
    * DUnit knows about.
    *
-   * @see VM#invoke(Runnable)
+   * @see VM#invoke(SerializableRunnableIF)
    */
   public static void invokeInEveryVM(SerializableRunnable work) {
     for (int h = 0; h < Host.getHostCount(); h++) {
@@ -188,7 +188,7 @@ public abstract class DistributedTestCase extends TestCase implements java.io.Se
    * DUnit knows about.
    *
    * @return a Map of results, where the key is the VM and the value is the result
-   * @see VM#invoke(Callable)
+   * @see VM#invoke(SerializableCallableIF)
    */
   protected static Map invokeInEveryVM(SerializableCallable work) {
     HashMap ret = new HashMap();
@@ -253,7 +253,7 @@ public abstract class DistributedTestCase extends TestCase implements java.io.Se
    * its execution is repeated, until no assertion failure occurs or
    * repeatTimeout milliseconds have passed.
    *
-   * @see VM#invoke(Runnable)
+   * @see VM#invoke(SerializableRunnableIF)
    */
   protected void invokeInEveryVMRepeatingIfNecessary(RepeatableRunnable work) {
     for (int h = 0; h < Host.getHostCount(); h++) {
@@ -467,7 +467,7 @@ public abstract class DistributedTestCase extends TestCase implements java.io.Se
    * Note: "final" was removed so that WANTestBase can override this method.
    * This was part of the xd offheap merge.
    *
-   * @see hydra.DistributedConnectionMgr#connect
+   * see hydra.DistributedConnectionMgr#connect
    * @since 3.0
    */
   public /*final*/ InternalDistributedSystem getSystem(Properties props) {
@@ -1200,7 +1200,7 @@ public abstract class DistributedTestCase extends TestCase implements java.io.Se
    * Wait for a thread to join
    * @param t thread to wait on
    * @param ms maximum time to wait
-   * @throws AssertionFailure if the thread does not terminate
+   * @throws AssertionError if the thread does not terminate
    */
   static public void join(Thread t, long ms, LogWriter logger) {
     final long tilt = System.currentTimeMillis() + ms;

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/172135e2/gemfire-core/src/test/java/com/gemstone/gemfire/test/dunit/RMIException.java
----------------------------------------------------------------------
diff --git a/gemfire-core/src/test/java/com/gemstone/gemfire/test/dunit/RMIException.java b/gemfire-core/src/test/java/com/gemstone/gemfire/test/dunit/RMIException.java
index b1f262b..8a555d2 100644
--- a/gemfire-core/src/test/java/com/gemstone/gemfire/test/dunit/RMIException.java
+++ b/gemfire-core/src/test/java/com/gemstone/gemfire/test/dunit/RMIException.java
@@ -39,7 +39,7 @@ import com.gemstone.gemfire.GemFireException;
  * The stack trace of the exception returned by {@link #getCause()}
  * may not be available.
  *
- * @see hydra.RemoteTestModuleIF
+ * see hydra.RemoteTestModuleIF
  *
  * @author David Whitlock
  *

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/172135e2/gemfire-core/src/test/java/com/gemstone/gemfire/test/dunit/SerializableCallable.java
----------------------------------------------------------------------
diff --git a/gemfire-core/src/test/java/com/gemstone/gemfire/test/dunit/SerializableCallable.java b/gemfire-core/src/test/java/com/gemstone/gemfire/test/dunit/SerializableCallable.java
index 60c20e3..e330693 100644
--- a/gemfire-core/src/test/java/com/gemstone/gemfire/test/dunit/SerializableCallable.java
+++ b/gemfire-core/src/test/java/com/gemstone/gemfire/test/dunit/SerializableCallable.java
@@ -22,7 +22,7 @@ import java.util.concurrent.Callable;
 /**
  * This interface provides both {@link Serializable} and {@link
  * Callable}.  It is often used in conjunction with {@link
- * VM#invoke(Callable)}.
+ * VM#invoke(SerializableCallableIF)}.
  *
  * <PRE>
  * public void testRepilcatedRegionPut() {

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/172135e2/gemfire-core/src/test/java/com/gemstone/gemfire/test/dunit/SerializableRunnable.java
----------------------------------------------------------------------
diff --git a/gemfire-core/src/test/java/com/gemstone/gemfire/test/dunit/SerializableRunnable.java b/gemfire-core/src/test/java/com/gemstone/gemfire/test/dunit/SerializableRunnable.java
index 5798861..658924a 100644
--- a/gemfire-core/src/test/java/com/gemstone/gemfire/test/dunit/SerializableRunnable.java
+++ b/gemfire-core/src/test/java/com/gemstone/gemfire/test/dunit/SerializableRunnable.java
@@ -21,7 +21,7 @@ import java.io.Serializable;
 /**
  * This interface provides both {@link Serializable} and {@link
  * Runnable}.  It is often used in conjunction with {@link
- * VM#invoke(Runnable)}.
+ * VM#invoke(SerializableRunnableIF)}.
  *
  * <PRE>
  * public void testRegionPutGet() {

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/172135e2/gemfire-core/src/test/java/com/gemstone/gemfire/test/dunit/VM.java
----------------------------------------------------------------------
diff --git a/gemfire-core/src/test/java/com/gemstone/gemfire/test/dunit/VM.java b/gemfire-core/src/test/java/com/gemstone/gemfire/test/dunit/VM.java
index 7abd20f..0d16196 100644
--- a/gemfire-core/src/test/java/com/gemstone/gemfire/test/dunit/VM.java
+++ b/gemfire-core/src/test/java/com/gemstone/gemfire/test/dunit/VM.java
@@ -1299,9 +1299,9 @@ public class VM implements java.io.Serializable {
    * runner.
    *
    * @throws RMIException if an exception occurs while bouncing this VM, for
-   *  example a HydraTimeoutException if the VM fails to stop within {@link
-   *  hydra.Prms#maxClientShutdownWaitSec} or restart within {@link
-   *  hydra.Prms#maxClientStartupWaitSec}.
+   *  example a HydraTimeoutException if the VM fails to stop within 
+   *  hydra.Prms#maxClientShutdownWaitSec or restart within 
+   *  hydra.Prms#maxClientStartupWaitSec.
    */
   public synchronized void bounce() {
     if (!this.available) {

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/172135e2/gemfire-core/src/test/java/com/gemstone/gemfire/util/JSR166TestCase.java
----------------------------------------------------------------------
diff --git a/gemfire-core/src/test/java/com/gemstone/persistence/logging/Logger.java b/gemfire-core/src/test/java/com/gemstone/persistence/logging/Logger.java
index 23f68fe..364f353 100644
--- a/gemfire-core/src/test/java/com/gemstone/persistence/logging/Logger.java
+++ b/gemfire-core/src/test/java/com/gemstone/persistence/logging/Logger.java
@@ -23,7 +23,7 @@ import java.util.*;
  * given level associated with it.  There are a number of convenience
  * methods for logging events.  Events with a level above a certain
  * are written to <code>System.err</code>.  The default level is
- * {@link LEVEL#INFO LEVEL.INFO}
+ * INFO
  */
 public class Logger {
   private static boolean DEBUG = Boolean.getBoolean("Logging.DEBUG");

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/172135e2/gemfire-core/src/test/java/com/gemstone/sequence/gemfire/GemfireSequenceDisplay.java
----------------------------------------------------------------------
diff --git a/gemfire-core/src/test/java/com/gemstone/sequence/gemfire/GemfireSequenceDisplay.java b/gemfire-core/src/test/java/com/gemstone/sequence/gemfire/GemfireSequenceDisplay.java
index b4ee5b8..6481a30 100644
--- a/gemfire-core/src/test/java/com/gemstone/sequence/gemfire/GemfireSequenceDisplay.java
+++ b/gemfire-core/src/test/java/com/gemstone/sequence/gemfire/GemfireSequenceDisplay.java
@@ -224,13 +224,6 @@ public class GemfireSequenceDisplay {
     return sequenceDiagram;
   }
 
-  /**
-   * @param graphId 
-   * @param lifeline 
-   * @param graphs
-   * @param dest
-   * @return
-   */
   private static LifelineState createState(Lifeline lifeline, GraphSet graphs, Vertex dest) {
     long start = dest.getTimestamp();
     long end = dest.getNextVertexOnDest() == null ? graphs.getMaxTime() : dest.getNextVertexOnDest().getTimestamp();

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/172135e2/gemfire-core/src/test/java/hydra/GsRandom.java
----------------------------------------------------------------------
diff --git a/gemfire-core/src/test/java/hydra/GsRandom.java b/gemfire-core/src/test/java/hydra/GsRandom.java
index 61b16b0..bed02da 100644
--- a/gemfire-core/src/test/java/hydra/GsRandom.java
+++ b/gemfire-core/src/test/java/hydra/GsRandom.java
@@ -83,7 +83,6 @@ public class GsRandom extends java.util.Random implements Serializable {
     * There is a hack here to prevent '}' so as to eliminate the possiblity 
     * of generating a sequence which would falsely get marked as a suspect
     * string while we are matching the pattern <code>{[0-9]+}</code>.
-    * {@link https://svn.gemstone.com/trac/gemfire/ticket/40415}
     * @return the next pseudorandom, uniformly distributed <code>char</code>
     *         value from this random number generator's sequence.
     */

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/172135e2/gemfire-core/src/test/java/hydra/log/AnyLogWriter.java
----------------------------------------------------------------------
diff --git a/gemfire-core/src/test/java/hydra/log/AnyLogWriter.java b/gemfire-core/src/test/java/hydra/log/AnyLogWriter.java
index c857196..369f35b 100644
--- a/gemfire-core/src/test/java/hydra/log/AnyLogWriter.java
+++ b/gemfire-core/src/test/java/hydra/log/AnyLogWriter.java
@@ -31,10 +31,10 @@ import java.io.*;
 /**
  *
  *  A {@link com.gemstone.gemfire.LogWriter} that writes to a file logger,
- *  depending on whether it is turned on via {@link LogPrms#file_logging}.
+ *  depending on whether it is turned on via LogPrms#file_logging.
  *  <p>
  *  The log level query methods answer true if a file logger is active and
- *  answer true.  See {@link LogPrms#file_logLevel}.
+ *  answer true.  See LogPrms#file_logLevel.
  */
 
 public class AnyLogWriter implements InternalLogWriter {

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/172135e2/gemfire-core/src/test/java/security/AuthzCredentialGenerator.java
----------------------------------------------------------------------
diff --git a/gemfire-core/src/test/java/security/AuthzCredentialGenerator.java b/gemfire-core/src/test/java/security/AuthzCredentialGenerator.java
index d5e4915..e15a60a 100644
--- a/gemfire-core/src/test/java/security/AuthzCredentialGenerator.java
+++ b/gemfire-core/src/test/java/security/AuthzCredentialGenerator.java
@@ -335,7 +335,7 @@ public abstract class AuthzCredentialGenerator {
    * perform the given {@link OperationCode}s for the given regions. The
    * credentials are required to be valid for authentication.
    * 
-   * @param opCode
+   * @param opCodes
    *                the {@link OperationCode}s of the operations requiring
    *                authorization failure; should not be null
    * @param regionNames
@@ -407,9 +407,6 @@ public abstract class AuthzCredentialGenerator {
    * @param regionNames
    *                list of the region names requiring authorization; a value of
    *                null indicates all regions
-   * @param index
-   *                used to generate multiple such credentials by passing
-   *                different values for this
    * 
    * @return the number of principals allowed to perform the given operation in
    *         the given region

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/172135e2/gemfire-core/src/test/java/security/CredentialGenerator.java
----------------------------------------------------------------------
diff --git a/gemfire-core/src/test/java/security/CredentialGenerator.java b/gemfire-core/src/test/java/security/CredentialGenerator.java
index c16a8a1..7a430f1 100644
--- a/gemfire-core/src/test/java/security/CredentialGenerator.java
+++ b/gemfire-core/src/test/java/security/CredentialGenerator.java
@@ -58,7 +58,7 @@ public abstract class CredentialGenerator {
    * overflowed. Note the methods and fields for existing schemes and add for
    * the new one in a similar manner.</li>
    * <li>Add an implementation for {@link CredentialGenerator}.</li>
-   * <li>Modify the {@link CredentialGenerator.Factory#create} method to add
+   * <li>Modify the CredentialGenerator.Factory#create [no such Factory exists] method to add
    * creation of an instance of the new implementation for the
    * <code>ClassCode</code> enumeration value.</li>
    * </ul>

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/172135e2/gemfire-cq/src/test/java/com/gemstone/gemfire/cache/query/cq/dunit/CqStatsOptimizedExecuteDUnitTest.java
----------------------------------------------------------------------
diff --git a/gemfire-cq/src/test/java/com/gemstone/gemfire/cache/query/cq/dunit/CqStatsOptimizedExecuteDUnitTest.java b/gemfire-cq/src/test/java/com/gemstone/gemfire/cache/query/cq/dunit/CqStatsOptimizedExecuteDUnitTest.java
index f52d655..987a70a 100644
--- a/gemfire-cq/src/test/java/com/gemstone/gemfire/cache/query/cq/dunit/CqStatsOptimizedExecuteDUnitTest.java
+++ b/gemfire-cq/src/test/java/com/gemstone/gemfire/cache/query/cq/dunit/CqStatsOptimizedExecuteDUnitTest.java
@@ -21,8 +21,7 @@ import com.gemstone.gemfire.cache.query.internal.cq.CqServiceImpl;
 import com.gemstone.gemfire.test.dunit.SerializableRunnable;
 
 /**
- * Test class for testing {@link CqService#EXECUTE_QUERY_DURING_INIT} flag
- *
+ * Test class for testing {@link CqServiceImpl#EXECUTE_QUERY_DURING_INIT} flag
  */
 public class CqStatsOptimizedExecuteDUnitTest extends CqStatsDUnitTest{
 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/172135e2/gemfire-cq/src/test/java/com/gemstone/gemfire/cache/query/cq/dunit/CqStatsUsingPoolOptimizedExecuteDUnitTest.java
----------------------------------------------------------------------
diff --git a/gemfire-cq/src/test/java/com/gemstone/gemfire/cache/query/cq/dunit/CqStatsUsingPoolOptimizedExecuteDUnitTest.java b/gemfire-cq/src/test/java/com/gemstone/gemfire/cache/query/cq/dunit/CqStatsUsingPoolOptimizedExecuteDUnitTest.java
index 8723eb3..95eb789 100644
--- a/gemfire-cq/src/test/java/com/gemstone/gemfire/cache/query/cq/dunit/CqStatsUsingPoolOptimizedExecuteDUnitTest.java
+++ b/gemfire-cq/src/test/java/com/gemstone/gemfire/cache/query/cq/dunit/CqStatsUsingPoolOptimizedExecuteDUnitTest.java
@@ -21,8 +21,7 @@ import com.gemstone.gemfire.cache.query.internal.cq.CqServiceImpl;
 import com.gemstone.gemfire.test.dunit.SerializableRunnable;
 
 /**
- * Test class for testing {@link CqService#EXECUTE_QUERY_DURING_INIT} flag
- *
+ * Test class for testing {@link CqServiceImpl#EXECUTE_QUERY_DURING_INIT} flag
  */
 public class CqStatsUsingPoolOptimizedExecuteDUnitTest extends CqStatsUsingPoolDUnitTest{
 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/172135e2/gemfire-cq/src/test/java/com/gemstone/gemfire/internal/cache/RemoteCQTransactionDUnitTest.java
----------------------------------------------------------------------
diff --git a/gemfire-cq/src/test/java/com/gemstone/gemfire/internal/cache/RemoteCQTransactionDUnitTest.java b/gemfire-cq/src/test/java/com/gemstone/gemfire/internal/cache/RemoteCQTransactionDUnitTest.java
index 3722afb..42d367c 100755
--- a/gemfire-cq/src/test/java/com/gemstone/gemfire/internal/cache/RemoteCQTransactionDUnitTest.java
+++ b/gemfire-cq/src/test/java/com/gemstone/gemfire/internal/cache/RemoteCQTransactionDUnitTest.java
@@ -614,8 +614,6 @@ public class RemoteCQTransactionDUnitTest extends CacheTestCase {
   }
   
   /**
-   * @param ds1
-   * @param pr
    * @return first key found on the given member
    */
   CustId getKeyOnMember(final DistributedMember owner,
@@ -631,10 +629,7 @@ public class RemoteCQTransactionDUnitTest extends CacheTestCase {
     }
     return retVal;
   }
-  /**
-   * @param i
-   * @return
-   */
+
   protected Set<Customer> getCustomerSet(int size) {
     Set<Customer> expectedSet = new HashSet<Customer>();
     for (int i=0; i<size; i++) {

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/172135e2/gemfire-joptsimple/src/main/java/joptsimple/internal/AbbreviationMap.java
----------------------------------------------------------------------
diff --git a/gemfire-joptsimple/src/main/java/joptsimple/internal/AbbreviationMap.java b/gemfire-joptsimple/src/main/java/joptsimple/internal/AbbreviationMap.java
index 8394f59..35fad89 100644
--- a/gemfire-joptsimple/src/main/java/joptsimple/internal/AbbreviationMap.java
+++ b/gemfire-joptsimple/src/main/java/joptsimple/internal/AbbreviationMap.java
@@ -54,7 +54,6 @@ import java.util.TreeMap;
  *
  * @param <V> a constraint on the types of the values in the map
  * @author <a href="mailto:pholser@alumni.rice.edu">Paul Holser</a>
- * @see <a href="http://www.perldoc.com/perl5.8.0/lib/Text/Abbrev.html">Perl's Text::Abbrev module</a>
  */
 public class AbbreviationMap<V> {
     private String key;

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/172135e2/gemfire-json/src/main/java/org/json/JSONObject.java
----------------------------------------------------------------------
diff --git a/gemfire-json/src/main/java/org/json/JSONObject.java b/gemfire-json/src/main/java/org/json/JSONObject.java
index 6c478db..24f5cc7 100755
--- a/gemfire-json/src/main/java/org/json/JSONObject.java
+++ b/gemfire-json/src/main/java/org/json/JSONObject.java
@@ -165,8 +165,6 @@ public class JSONObject {
      * Missing keys are ignored.
      * @param jo A JSONObject.
      * @param names An array of strings.
-     * @throws JSONException
-     * @exception JSONException If a value is a non-finite number or if a name is duplicated.
      */
     public JSONObject(JSONObject jo, String[] names) {
         this();
@@ -241,7 +239,6 @@ public class JSONObject {
      *
      * @param map A map object that can be used to initialize the contents of
      *  the JSONObject.
-     * @throws JSONException
      */
     public JSONObject(Map map) {
         this.map = new LinkedHashMap();

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/172135e2/gemfire-lucene/src/main/java/com/gemstone/gemfire/cache/lucene/LuceneQueryFactory.java
----------------------------------------------------------------------
diff --git a/gemfire-lucene/src/main/java/com/gemstone/gemfire/cache/lucene/LuceneQueryFactory.java b/gemfire-lucene/src/main/java/com/gemstone/gemfire/cache/lucene/LuceneQueryFactory.java
index b707c52..aa4d004 100644
--- a/gemfire-lucene/src/main/java/com/gemstone/gemfire/cache/lucene/LuceneQueryFactory.java
+++ b/gemfire-lucene/src/main/java/com/gemstone/gemfire/cache/lucene/LuceneQueryFactory.java
@@ -77,8 +77,8 @@ public interface LuceneQueryFactory {
    * @param regionName region name
    * @param indexName index name
    * @param queryString query string in lucene QueryParser's syntax
-   * @param K the key type in the query results
-   * @param V the value type in the query results
+   * @param <K> the key type in the query results
+   * @param <V> the value type in the query results
    * @return LuceneQuery object
    * @throws ParseException
    */
@@ -87,14 +87,13 @@ public interface LuceneQueryFactory {
 
   /**
    * Creates a wrapper object for Lucene's Query object. This {@link LuceneQuery} builder method could be used in
-   * advanced cases, such as cases where Lucene's Query object construction needs Lucene's API over query string. The
-   * {@link QueryDeserializer} will be used to re-construct the Lucene Query object on remote hosts.
+   * advanced cases, such as cases where Lucene's Query object construction needs Lucene's API over query string.
    * 
    * @param indexName index name
    * @param regionName region name
    * @param provider constructs and provides a Lucene Query object
-   * @param K the key type in the query results
-   * @param V the value type in the query results
+   * @param <K> the key type in the query results
+   * @param <V> the value type in the query results
    * @return LuceneQuery object
    */
   public <K, V> LuceneQuery<K, V> create(String indexName, String regionName, LuceneQueryProvider provider);

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/172135e2/gemfire-lucene/src/main/java/com/gemstone/gemfire/cache/lucene/LuceneQueryProvider.java
----------------------------------------------------------------------
diff --git a/gemfire-lucene/src/main/java/com/gemstone/gemfire/cache/lucene/LuceneQueryProvider.java b/gemfire-lucene/src/main/java/com/gemstone/gemfire/cache/lucene/LuceneQueryProvider.java
index 8e3500e..ef60158 100644
--- a/gemfire-lucene/src/main/java/com/gemstone/gemfire/cache/lucene/LuceneQueryProvider.java
+++ b/gemfire-lucene/src/main/java/com/gemstone/gemfire/cache/lucene/LuceneQueryProvider.java
@@ -38,7 +38,7 @@ import com.gemstone.gemfire.cache.query.QueryException;
 public interface LuceneQueryProvider extends Serializable {
   /**
    * @return A Lucene Query object which could be used for executing Lucene Search on indexed data
-   * @param The local lucene index the query is being constructed against.
+   * @param index local lucene index the query is being constructed against.
    * @throws QueryException if the provider fails to construct the query object
    */
   public Query getQuery(LuceneIndex index) throws QueryException;

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/172135e2/gemfire-lucene/src/main/java/com/gemstone/gemfire/cache/lucene/LuceneService.java
----------------------------------------------------------------------
diff --git a/gemfire-lucene/src/main/java/com/gemstone/gemfire/cache/lucene/LuceneService.java b/gemfire-lucene/src/main/java/com/gemstone/gemfire/cache/lucene/LuceneService.java
index fbd6dad..f4c665b 100644
--- a/gemfire-lucene/src/main/java/com/gemstone/gemfire/cache/lucene/LuceneService.java
+++ b/gemfire-lucene/src/main/java/com/gemstone/gemfire/cache/lucene/LuceneService.java
@@ -25,8 +25,7 @@ import com.gemstone.gemfire.annotations.Experimental;
 import com.gemstone.gemfire.cache.GemFireCache;
 
 /**
- * LuceneService instance is a singleton for each cache. It will be created in cache 
- * constructor and get its reference via {@link GemFireCache#getLuceneService()}.
+ * LuceneService instance is a singleton for each cache.
  * 
  * It provides handle for managing the {@link LuceneIndex} and create the {@link LuceneQuery}
  * via {@link LuceneQueryFactory}
@@ -73,11 +72,6 @@ public interface LuceneService {
   
   /**
    * Create a lucene index using default analyzer.
-   * 
-   * @param indexName
-   * @param regionPath
-   * @param fields
-   * @return LuceneIndex object
    */
   public void createIndex(String indexName, String regionPath, String... fields);
   
@@ -87,7 +81,6 @@ public interface LuceneService {
    * @param indexName index name
    * @param regionPath region name
    * @param analyzerPerField analyzer per field map
-   * @return LuceneIndex object
    * @deprecated TODO This feature is not yet implemented
    */
   @Deprecated

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/172135e2/gemfire-lucene/src/main/java/com/gemstone/gemfire/cache/lucene/internal/repository/RepositoryManager.java
----------------------------------------------------------------------
diff --git a/gemfire-lucene/src/main/java/com/gemstone/gemfire/cache/lucene/internal/repository/RepositoryManager.java b/gemfire-lucene/src/main/java/com/gemstone/gemfire/cache/lucene/internal/repository/RepositoryManager.java
index 20c2d51..8f8d202 100644
--- a/gemfire-lucene/src/main/java/com/gemstone/gemfire/cache/lucene/internal/repository/RepositoryManager.java
+++ b/gemfire-lucene/src/main/java/com/gemstone/gemfire/cache/lucene/internal/repository/RepositoryManager.java
@@ -37,7 +37,6 @@ public interface RepositoryManager {
    * Returns a collection of {@link IndexRepository} instances hosting index data of the input list of bucket ids. The
    * bucket needs to be present on this member.
    * 
-   * @param localDataSet The local data set of a function
    * @return a collection of {@link IndexRepository} instances
    * @throws BucketNotFoundException if any of the requested buckets is not found on this member
    */

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/172135e2/gemfire-pulse/src/main/java/com/vmware/gemfire/tools/pulse/internal/data/DataBrowser.java
----------------------------------------------------------------------
diff --git a/gemfire-pulse/src/main/java/com/vmware/gemfire/tools/pulse/internal/data/DataBrowser.java b/gemfire-pulse/src/main/java/com/vmware/gemfire/tools/pulse/internal/data/DataBrowser.java
index 4810716..dbad2df 100644
--- a/gemfire-pulse/src/main/java/com/vmware/gemfire/tools/pulse/internal/data/DataBrowser.java
+++ b/gemfire-pulse/src/main/java/com/vmware/gemfire/tools/pulse/internal/data/DataBrowser.java
@@ -149,7 +149,6 @@ public class DataBrowser {
    * 
    * @param userId
    *          Logged in User's Id
-   * @throws JSONException
    */
   public JSONArray getQueryHistoryByUserId(String userId) {
 
@@ -233,8 +232,6 @@ public class DataBrowser {
    * generateQueryKey method stores queries in query history file.
    * 
    * @return Boolean true is operation is successful, false otherwise
-   * @param properties
-   *          a collection queries in form of key and values
    */
   private boolean storeQueriesInFile(JSONObject queries) {
     boolean operationStatus = false;

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/172135e2/gemfire-pulse/src/main/java/com/vmware/gemfire/tools/pulse/internal/data/JMXDataUpdater.java
----------------------------------------------------------------------
diff --git a/gemfire-pulse/src/main/java/com/vmware/gemfire/tools/pulse/internal/data/JMXDataUpdater.java b/gemfire-pulse/src/main/java/com/vmware/gemfire/tools/pulse/internal/data/JMXDataUpdater.java
index 0e4bd14..1cd5fd7 100644
--- a/gemfire-pulse/src/main/java/com/vmware/gemfire/tools/pulse/internal/data/JMXDataUpdater.java
+++ b/gemfire-pulse/src/main/java/com/vmware/gemfire/tools/pulse/internal/data/JMXDataUpdater.java
@@ -971,16 +971,6 @@ public class JMXDataUpdater implements IClusterUpdater, NotificationListener {
   /**
    * function used for getting list of Gateway Senders from mBean for giving
    * member and update the list of gateway senders for respective member object
-   *
-   * @param mbeanName
-   * @param memberName
-   * @throws InstanceNotFoundException
-   * @throws IntrospectionException
-   * @throws ReflectionException
-   * @throws IOException
-   * @throws AttributeNotFoundException
-   * @throws MBeanException
-   *
    */
   private void updateGatewaySender(ObjectName mbeanName) throws IOException {
 
@@ -1089,16 +1079,6 @@ public class JMXDataUpdater implements IClusterUpdater, NotificationListener {
   /**
    * function used for getting list of Gateway Senders from mBean for giving
    * member and update the list of gateway senders for respective member object
-   *
-   * @param mbeanName
-   * @param memberName
-   * @throws InstanceNotFoundException
-   * @throws IntrospectionException
-   * @throws ReflectionException
-   * @throws IOException
-   * @throws AttributeNotFoundException
-   * @throws MBeanException
-   *
    */
   private void updateAsyncEventQueue(ObjectName mbeanName) throws IOException {
     try {
@@ -1145,16 +1125,6 @@ public class JMXDataUpdater implements IClusterUpdater, NotificationListener {
   /**
    * function used for getting a Gateway Receiver from mBean for giving member
    * and update the gateway receiver for respective member object
-   *
-   * @param mbeanName
-   * @param memberName
-   * @throws InstanceNotFoundException
-   * @throws IntrospectionException
-   * @throws ReflectionException
-   * @throws IOException
-   * @throws AttributeNotFoundException
-   * @throws MBeanException
-   *
    */
   private void updateGatewayReceiver(ObjectName mbeanName) throws IOException {
 
@@ -1191,16 +1161,6 @@ public class JMXDataUpdater implements IClusterUpdater, NotificationListener {
   /**
    * function used for getting member clients from mbean and update the clients
    * information in member object's client arraylist
-   *
-   * @param mbeanName
-   * @param memberName
-   * @throws InstanceNotFoundException
-   * @throws IntrospectionException
-   * @throws ReflectionException
-   * @throws IOException
-   * @throws MBeanException
-   * @throws AttributeNotFoundException
-   *
    */
   private void updateMemberClient(ObjectName mbeanName) throws IOException {
 
@@ -1452,12 +1412,6 @@ public class JMXDataUpdater implements IClusterUpdater, NotificationListener {
    *
    * @param mbeanName
    *          Cluster Region MBean
-   * @throws IOException
-   * @throws ReflectionException
-   * @throws IntrospectionException
-   * @throws InstanceNotFoundException
-   * @throws MBeanException
-   * @throws AttributeNotFoundException
    */
   private void updateClusterRegion(ObjectName mbeanName) throws IOException {
 
@@ -1780,14 +1734,6 @@ public class JMXDataUpdater implements IClusterUpdater, NotificationListener {
   /**
    * function used to iterate through all member attributes and return the
    * updated member
-   *
-   * @param attrs
-   * @param mbeanName
-   * @param member
-   * @return
-   * @throws IOException
-   * @throws ReflectionException
-   * @throws InstanceNotFoundException
    */
   private Cluster.Member initializeMember(ObjectName mbeanName,
       Cluster.Member member) throws InstanceNotFoundException,
@@ -2004,13 +1950,6 @@ public class JMXDataUpdater implements IClusterUpdater, NotificationListener {
    *
    * @param mbeanName
    *          Cluster Member MBean
-   * @throws IOException
-   * @throws ReflectionException
-   * @throws IntrospectionException
-   * @throws InstanceNotFoundException
-   * @throws MBeanException
-   * @throws AttributeNotFoundException
-   *
    */
   private void updateClusterMember(ObjectName mbeanName) throws IOException {
 
@@ -2071,11 +2010,6 @@ public class JMXDataUpdater implements IClusterUpdater, NotificationListener {
    * function used to handle Float data type if the value for mbean for an
    * attribute is null then return 0.0 as default value else return the
    * attribute value
-   *
-   * @param name
-   * @param mbs
-   * @param mBeanName
-   * @return
    */
   private Float getFloatAttribute(Object object, String name) {
     try {
@@ -2102,11 +2036,6 @@ public class JMXDataUpdater implements IClusterUpdater, NotificationListener {
    * function used to handle Integer data type if the value for mbean for an
    * attribute is null then return 0 as default value else return the attribute
    * value
-   *
-   * @param name
-   * @param mbs
-   * @param mBeanName
-   * @return
    */
   private Integer getIntegerAttribute(Object object, String name) {
     try {
@@ -2133,11 +2062,6 @@ public class JMXDataUpdater implements IClusterUpdater, NotificationListener {
    * function used to handle Long data type if the value for mbean for an
    * attribute is null then return 0 as default value else return the attribute
    * value
-   *
-   * @param name
-   * @param mbs
-   * @param mBeanName
-   * @return
    */
   private Long getLongAttribute(Object object, String name) {
     try {
@@ -2165,11 +2089,6 @@ public class JMXDataUpdater implements IClusterUpdater, NotificationListener {
    * function used to handle String data type if the value for mbean for an
    * attribute is null then return the empty string as default value else return
    * the attribute value
-   *
-   * @param name
-   * @param mbs
-   * @param mBeanName
-   * @return
    */
   private String getStringAttribute(Object object, String name) {
     try {
@@ -2196,11 +2115,6 @@ public class JMXDataUpdater implements IClusterUpdater, NotificationListener {
    * function used to handle Boolean data type if the value for mbean for an
    * attribute is null then return false as default value else return the
    * attribute value
-   *
-   * @param name
-   * @param mbs
-   * @param mBeanName
-   * @return
    */
   private Boolean getBooleanAttribute(Object object, String name) {
     try {
@@ -2227,11 +2141,6 @@ public class JMXDataUpdater implements IClusterUpdater, NotificationListener {
    * function used to handle Double data type if the value for mbean for an
    * attribute is null then return 0.0 as default value else return the
    * attribute value
-   *
-   * @param name
-   * @param mbs
-   * @param mBeanName
-   * @return
    */
   private Double getDoubleAttribute(Object object, String name) {
     try {

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/172135e2/gemfire-pulse/src/main/java/com/vmware/gemfire/tools/pulse/internal/data/JmxManagerFinder.java
----------------------------------------------------------------------
diff --git a/gemfire-pulse/src/main/java/com/vmware/gemfire/tools/pulse/internal/data/JmxManagerFinder.java b/gemfire-pulse/src/main/java/com/vmware/gemfire/tools/pulse/internal/data/JmxManagerFinder.java
index 38c614e..3fb6d6a 100644
--- a/gemfire-pulse/src/main/java/com/vmware/gemfire/tools/pulse/internal/data/JmxManagerFinder.java
+++ b/gemfire-pulse/src/main/java/com/vmware/gemfire/tools/pulse/internal/data/JmxManagerFinder.java
@@ -48,10 +48,6 @@ public class JmxManagerFinder {
 
   private final static PulseLogWriter LOGGER = PulseLogWriter.getLogger();
 
-  /**
-   * @param args
-   * @throws IOException
-   */
   /*
    * public static void main(String[] args) throws IOException { if (args.length
    * != 2) { System.err.println(

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/172135e2/gemfire-pulse/src/main/java/com/vmware/gemfire/tools/pulse/internal/json/JSONObject.java
----------------------------------------------------------------------
diff --git a/gemfire-pulse/src/main/java/com/vmware/gemfire/tools/pulse/internal/json/JSONObject.java b/gemfire-pulse/src/main/java/com/vmware/gemfire/tools/pulse/internal/json/JSONObject.java
index 427d051..d04b1f4 100644
--- a/gemfire-pulse/src/main/java/com/vmware/gemfire/tools/pulse/internal/json/JSONObject.java
+++ b/gemfire-pulse/src/main/java/com/vmware/gemfire/tools/pulse/internal/json/JSONObject.java
@@ -154,8 +154,6 @@ public class JSONObject {
      * Missing keys are ignored.
      * @param jo A JSONObject.
      * @param names An array of strings.
-     * @throws JSONException
-     * @exception JSONException If a value is a non-finite number or if a name is duplicated.
      */
     public JSONObject(JSONObject jo, String[] names) {
         this();
@@ -230,7 +228,6 @@ public class JSONObject {
      *
      * @param map A map object that can be used to initialize the contents of
      *  the JSONObject.
-     * @throws JSONException
      */
     public JSONObject(Map map) {
         this.map = new HashMap();

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/172135e2/gemfire-pulse/src/main/java/com/vmware/gemfire/tools/pulse/internal/json/JSONWriter.java
----------------------------------------------------------------------
diff --git a/gemfire-pulse/src/main/java/com/vmware/gemfire/tools/pulse/internal/json/JSONWriter.java b/gemfire-pulse/src/main/java/com/vmware/gemfire/tools/pulse/internal/json/JSONWriter.java
index 1d3c7b3..7c1590e 100644
--- a/gemfire-pulse/src/main/java/com/vmware/gemfire/tools/pulse/internal/json/JSONWriter.java
+++ b/gemfire-pulse/src/main/java/com/vmware/gemfire/tools/pulse/internal/json/JSONWriter.java
@@ -264,7 +264,7 @@ public class JSONWriter {
 
     /**
      * Push an array or object scope.
-     * @param c The scope to open.
+     * @param jo The scope to open.
      * @throws JSONException If nesting is too deep.
      */
     private void push(JSONObject jo) throws JSONException {

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/172135e2/gemfire-pulse/src/main/java/com/vmware/gemfire/tools/pulse/internal/service/ClusterSelectedRegionsMemberService.java
----------------------------------------------------------------------
diff --git a/gemfire-pulse/src/main/java/com/vmware/gemfire/tools/pulse/internal/service/ClusterSelectedRegionsMemberService.java b/gemfire-pulse/src/main/java/com/vmware/gemfire/tools/pulse/internal/service/ClusterSelectedRegionsMemberService.java
index 74d6fff..f4430d5 100644
--- a/gemfire-pulse/src/main/java/com/vmware/gemfire/tools/pulse/internal/service/ClusterSelectedRegionsMemberService.java
+++ b/gemfire-pulse/src/main/java/com/vmware/gemfire/tools/pulse/internal/service/ClusterSelectedRegionsMemberService.java
@@ -98,9 +98,6 @@ public class ClusterSelectedRegionsMemberService implements PulseService {
 
   /**
    * Create JSON for selected cluster region's all members
-   *
-   * @param cluster, region path
-   * @return JSONObject Array List
    */
   private JSONObject getSelectedRegionsMembersJson(Cluster cluster, String selectedRegionFullPath) throws JSONException {
     PulseLogWriter LOGGER = PulseLogWriter.getLogger();

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/172135e2/gemfire-rebalancer/src/main/java/com/gemstone/gemfire/cache/util/AutoBalancer.java
----------------------------------------------------------------------
diff --git a/gemfire-rebalancer/src/main/java/com/gemstone/gemfire/cache/util/AutoBalancer.java b/gemfire-rebalancer/src/main/java/com/gemstone/gemfire/cache/util/AutoBalancer.java
index 48fec09..02d0c2a 100644
--- a/gemfire-rebalancer/src/main/java/com/gemstone/gemfire/cache/util/AutoBalancer.java
+++ b/gemfire-rebalancer/src/main/java/com/gemstone/gemfire/cache/util/AutoBalancer.java
@@ -98,7 +98,7 @@ public class AutoBalancer implements Declarable {
    * will be triggered if the total number of bytes rebalance operation may move
    * is more than this threshold, in percentage of the total data size.
    * <P>
-   * Default {@value AutoBalancer#DEFAULT_SIZE_THRESHOLD_PERCENT}
+   * Default value {@link #DEFAULT_SIZE_THRESHOLD_PERCENT}
    */
   public static final String SIZE_THRESHOLD_PERCENT = "size-threshold-percent";
 
@@ -116,7 +116,7 @@ public class AutoBalancer implements Declarable {
    * the total number of bytes rebalance operation may move is more than this
    * number of bytes.
    * <P>
-   * Default {@value AutoBalancer#DEFAULT_MINIMUM_SIZE}
+   * Default value {@link #DEFAULT_MINIMUM_SIZE}
    */
   public static final String MINIMUM_SIZE = "minimum-size";
 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/172135e2/gemfire-wan/src/main/java/com/gemstone/gemfire/internal/cache/wan/GatewaySenderEventRemoteDispatcher.java
----------------------------------------------------------------------
diff --git a/gemfire-wan/src/main/java/com/gemstone/gemfire/internal/cache/wan/GatewaySenderEventRemoteDispatcher.java b/gemfire-wan/src/main/java/com/gemstone/gemfire/internal/cache/wan/GatewaySenderEventRemoteDispatcher.java
index 9f0da9b..9da6748 100644
--- a/gemfire-wan/src/main/java/com/gemstone/gemfire/internal/cache/wan/GatewaySenderEventRemoteDispatcher.java
+++ b/gemfire-wan/src/main/java/com/gemstone/gemfire/internal/cache/wan/GatewaySenderEventRemoteDispatcher.java
@@ -268,7 +268,6 @@ public class GatewaySenderEventRemoteDispatcher implements
    * @return the <code>Connection</code>
    *
    * @throws GatewaySenderException
-   * @throws InterruptedException 
    */
   public Connection getConnection(boolean startAckReaderThread) throws GatewaySenderException{
     // IF the connection is null 

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/172135e2/gemfire-wan/src/test/java/com/gemstone/gemfire/internal/cache/wan/WANTestBase.java
----------------------------------------------------------------------
diff --git a/gemfire-wan/src/test/java/com/gemstone/gemfire/internal/cache/wan/WANTestBase.java b/gemfire-wan/src/test/java/com/gemstone/gemfire/internal/cache/wan/WANTestBase.java
index b3d49d3..f0c01ab 100644
--- a/gemfire-wan/src/test/java/com/gemstone/gemfire/internal/cache/wan/WANTestBase.java
+++ b/gemfire-wan/src/test/java/com/gemstone/gemfire/internal/cache/wan/WANTestBase.java
@@ -3579,7 +3579,6 @@ public class WANTestBase extends DistributedTestCase{
   /**
    * To be used only for ParallelGatewaySender.
    * @param senderId    Id of the ParallelGatewaySender
-   * @param numQueueEntries     Expected number of ParallelGatewaySenderQueue entries
    */
   public static int getPRQLocalSize(String senderId) {
     GatewaySender sender = null;

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/172135e2/gemfire-wan/src/test/java/com/gemstone/gemfire/internal/cache/wan/misc/WANConfigurationJUnitTest.java
----------------------------------------------------------------------
diff --git a/gemfire-wan/src/test/java/com/gemstone/gemfire/internal/cache/wan/misc/WANConfigurationJUnitTest.java b/gemfire-wan/src/test/java/com/gemstone/gemfire/internal/cache/wan/misc/WANConfigurationJUnitTest.java
index cb4907b..84eb365 100644
--- a/gemfire-wan/src/test/java/com/gemstone/gemfire/internal/cache/wan/misc/WANConfigurationJUnitTest.java
+++ b/gemfire-wan/src/test/java/com/gemstone/gemfire/internal/cache/wan/misc/WANConfigurationJUnitTest.java
@@ -288,8 +288,6 @@ public class WANConfigurationJUnitTest {
   
   /**
    * Test to validate that serial gateway sender attributes are correctly set
-   * 
-   * @throws IOException
    */
   @Test
   public void test_ValidateSerialGatewaySenderAttributes() {
@@ -344,8 +342,6 @@ public class WANConfigurationJUnitTest {
   
   /**
    * Test to validate that parallel gateway sender attributes are correctly set
-   * 
-   * @throws IOException
    */
   @Test
   public void test_ValidateParallelGatewaySenderAttributes() {
@@ -466,10 +462,6 @@ public class WANConfigurationJUnitTest {
    * "Cannot assign requested address" but gets
    * "Can't assign requested address". Timout after 150s to safeguard against
    * hanging on other platforms that may differ.
-   * 
-   * @see <a
-   *      href="https://svn.gemstone.com/trac/gemfire/ticket/51536">https://svn
-   *      .gemstone.com/trac/gemfire/ticket/51536<a>
    */
   @Test(timeout = 150000)
   public void test_ValidateGatwayReceiverAttributes_WrongBindAddress() {

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/172135e2/gemfire-wan/src/test/java/com/gemstone/gemfire/internal/cache/wan/wancommand/WANCommandTestBase.java
----------------------------------------------------------------------
diff --git a/gemfire-wan/src/test/java/com/gemstone/gemfire/internal/cache/wan/wancommand/WANCommandTestBase.java b/gemfire-wan/src/test/java/com/gemstone/gemfire/internal/cache/wan/wancommand/WANCommandTestBase.java
index d0ea193..2a91108 100644
--- a/gemfire-wan/src/test/java/com/gemstone/gemfire/internal/cache/wan/wancommand/WANCommandTestBase.java
+++ b/gemfire-wan/src/test/java/com/gemstone/gemfire/internal/cache/wan/wancommand/WANCommandTestBase.java
@@ -329,8 +329,6 @@ public class WANCommandTestBase extends CliCommandTestBase{
 
   /**
    * Enable system property gemfire.disableManagement false in each VM.
-   *
-   * @throws Exception
    */
   public void enableManagement() {
     invokeInEveryVM(new SerializableRunnable("Enable Management") {

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/172135e2/gradle/dependency-versions.properties
----------------------------------------------------------------------
diff --git a/gradle/dependency-versions.properties b/gradle/dependency-versions.properties
index 25f297d..4f68974 100644
--- a/gradle/dependency-versions.properties
+++ b/gradle/dependency-versions.properties
@@ -23,6 +23,7 @@ awaitility.version = 1.7.0
 bcel.version = 5.2
 catch-exception.version = 1.4.4
 catch-throwable.version = 1.4.4
+cdi-api.version = 1.2
 cglib.version = 3.1
 classmate.version = 0.9.0
 commons-collections.version = 3.2.1
@@ -52,6 +53,7 @@ jline.version = 2.12
 jmock.version = 2.8.1
 jna.version = 4.0.0
 json4s.version = 3.2.4
+jsr305.version = 3.0.1
 junit.version = 4.12
 JUnitParams.version = 1.0.4
 log4j.version = 2.5

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/172135e2/gradle/java.gradle
----------------------------------------------------------------------
diff --git a/gradle/java.gradle b/gradle/java.gradle
index 3ec105d..d166fca 100644
--- a/gradle/java.gradle
+++ b/gradle/java.gradle
@@ -102,5 +102,7 @@ subprojects {
     compile 'org.springframework:spring-web:' + project.'springframework.version'
     compile 'org.springframework:spring-webmvc:' + project.'springframework.version'
     compile 'com.github.stephenc.findbugs:findbugs-annotations:' + project.'stephenc-findbugs.version'
+    compile 'com.google.code.findbugs:jsr305:' + project.'jsr305.version'
+    compile 'javax.enterprise:cdi-api:' + project.'cdi-api.version'
   }
 }
diff --git a/gemfire-core/src/test/java/com/gemstone/gemfire/util/JSR166TestCase.java b/gemfire-core/src/test/java/com/gemstone/gemfire/util/JSR166TestCase.java
index 2baff7a..a5b8310 100755
--- a/gemfire-core/src/test/java/com/gemstone/gemfire/util/JSR166TestCase.java
+++ b/gemfire-core/src/test/java/com/gemstone/gemfire/util/JSR166TestCase.java
@@ -23,10 +23,13 @@
  */
 package com.gemstone.gemfire.util;
 
-import junit.framework.*;
-//import java.util.*;
-//import java.io.*;
-import java.security.*;
+import java.security.CodeSource;
+import java.security.Permission;
+import java.security.PermissionCollection;
+import java.security.Permissions;
+import java.security.ProtectionDomain;
+
+import junit.framework.TestCase;
 
 /**
  * Base class for JSR166 Junit TCK tests.  Defines some constants,
@@ -39,14 +42,14 @@ import java.security.*;
  * <ol>
  *
  * <li> All assertions in code running in generated threads must use
- * the forms {@link threadFail} , {@link threadAssertTrue} {@link
- * threadAssertEquals}, or {@link threadAssertNull}, (not
+ * the forms threadFail, threadAssertTrue, 
+ * threadAssertEquals, or threadAssertNull, (not
  * <tt>fail</tt>, <tt>assertTrue</tt>, etc.) It is OK (but not
  * particularly recommended) for other code to use these forms too.
  * Only the most typically used JUnit assertion methods are defined
  * this way, but enough to live with.</li>
  *
  * <li> If you override {@link setUp} or {@link tearDown}, make sure
  * to invoke <tt>super.setUp</tt> and <tt>super.tearDown</tt> within
  * them. These methods are used to clear and check for thread
  * assertion failures.</li>

http://git-wip-us.apache.org/repos/asf/incubator-geode/blob/172135e2/gemfire-core/src/test/java/com/gemstone/persistence/logging/Logger.java
----------------------------------------------------------------------
@@ -39,14 +42,14 @@ import java.security.*;
  * this way, but enough to live with.</li>
  *
- * <li> If you override {@link setUp} or {@link tearDown}, make sure
+ * <li> If you override {@link junit.framework.TestCase#setUp} or {@link junit.framework.TestCase#tearDown}, make sure
  * to invoke <tt>super.setUp</tt> and <tt>super.tearDown</tt> within
  * them. These methods are used to clear and check for thread